//----------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//      factor.h: --- classes related to rgsbackmodel task
//
//      DESCRIPTION:
//             Calculates the factors needed by rgs background model
//
//      CHANGE HISTORY:
//              AI, 2004-06-24: 1.0.0: - first version
//
//      AUTHOR:
//              A. Ibarra (AI), Thu Jun 24 15:31:40 GMT 2004
//
//
#ifndef FACTOR_H
#define FACTOR_H

#include <Dal.h>
#include <evselect.h>
#include <errstr.h>
#include <metatask.h>

#include <iomanip>
#include <vector>
#include <map>

#include "CalServer.h"
#include "Xmm.h"
#include "RgsBackgroundServer.h"


using namespace std;

class Factor {

 public:
  
  Factor();

  std::vector<double> calHistogram();
  void runEvselect();
  std::vector<double> getBins();
  XmmInstrument &getRGSunit();
  unsigned int getOrder();
  std::multimap<double,double> getMap();
  

 private:
  std::vector<double> bin;
  std::vector<double> factors;
  std::string rgsunit;
  unsigned int order;
  std::multimap<double, double> m;
  
};

#endif
