//----------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//      model.h: --- classes related to rgsbackmodel task
//
//      DESCRIPTION:
//             Calculates the new rate for the background model
//             and store the output in a new fits file called "Model.fits"
//
//      CHANGE HISTORY:
//              AI, 2004-06-25: 1.0.0: - first version
//
//      AUTHOR:
//              A. Ibarra (AI), Fri Jun 25 10:13:55 GMT 2004
//
//
#ifndef MODEL_H
#define MODEL_H

#include <Dal.h>
#include <evselect.h>
#include <errstr.h>
#include <metatask.h>

#include <iomanip>
#include <vector>

#include "CalServer.h"
#include "Xmm.h"
#include "RgsBackgroundServer.h"

using namespace std;

class Model  {

 public:

  //  Model(std::vector<double> bin, std::vector<double> factors,
  //	std::string order, std::string dirName, std::multimap<double, double> m,
  //	XmmInstrument &r, unsigned int to);

  Model(std::vector<double> bin, std::vector<double> factors,
  	XmmInstrument &r, unsigned int o);

  ~Model();

  void rateCal();
  void bkgModel(double *rate, double *errRate);

 private:
  std::vector<double> bin;
  std::vector<double> factors;
  XmmInstrument &rgsunit;

  double exposureTimeCCF;
  unsigned int _Num;
  unsigned int M;
  unsigned int order;


};

#endif
