/*
 rgsbkgmodelTest

   Authors:  Aitor Ibarra - ESA contractor (INSA)
         
   Description: Check if it is feasible to run rgsbkgmodel for the current ODF.
                If it is no possible to run rgsbkgmodel because of the lack of 
		data in the CCD9, or because of the number of channels is not 3400,
		the program exits with a -1.
 
   Comments: 
 
  $Id: rgsbkgmodelTest.cc,v 1.2 2006/05/09 19:42:58 aibarra Exp $
*/

#include "rgsbkgmodelTest.h"

#include <metatask.h>

#include "Factor.h"
#include "Model.h"

#include <Tracer.h>
#include <errstr.h>
#include "Xmm.h"
#include "ExceptionErrorHandler.h"
#include "SelectError.h"


#include <sstream>
#include <cmath>

using namespace SelectError;

void rgsbkgmodelTest ()
{
  PROC

    std::string sasdir;

  if (getenv("SAS_DIR")) 
    sasdir = getenv("SAS_DIR");
  else
    errstr << "Environmental variable SAS_DIR not defined " << Sas::error("SAS_DIR variable not found");
  
  
  string table(stringParameter("table"));

  DataSet*  tempDS = dataSetServer->open(table, Dal::Read); 
  

  //Get TLMAX14 attribute
  Table* tempTab = tempDS->table("EVENTS");
  
  Column *betaCol = tempTab->column("BETA_CHANNEL");
  
  Attribute* attribute;
  attribute = betaCol->attribute("TLMAX");

  // Check if the event file has the correct number of channels
  if ( betaCol->attribute("TLMAX")->asInt() != 3400 )
    {
      errstr << "Input event file incompatible with the background templates. "
	     << "Input file has "<< betaCol->attribute("TLMAX")->asInt() 
	     << " beta channels and it must have 3400. " 
	     << Sas::warning("incompatible event file");
      exit(1);
    }
  //Get TLMAX14 attribute
  

  /*
   * Check if there are data in CCD9. SOC-SPR-2600
   */
  ColumnData * CCDNRColData = tempTab->column("CCDNR")->data();
  int8 * ccdDat = CCDNRColData->int8Data();
  
  int ccd9Counter = 0;
  for (unsigned int i = 0 ; i < tempTab->rows() ; ++i)
    {
      if (ccdDat[i] == 9 )
	++ccd9Counter;
    }
  
  delete CCDNRColData;

  if (ccd9Counter == 0)
    {
      errstr << "Background light curve cannot be computed " 
	     << Sas::warning("No CCD 9 data");
      exit(1);
    }

  errstr << "rgsbkgmodelTest Test successfully passed."
	 <<  Sas::message(Msg::App, Msg::Verbose);

  dataSetServer->close(tempDS);
  ENDPROC
}
