//---------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//      checkbkgmodel.cc: --- test harness for rgsbkgmodel
//
//
//      CHANGE HISTORY:
//           AI, 2004-06-28: 1.0.0: - first version
//
//      REFERENCES:
//
//      AUTHOR:
//           A. Ibarra (AI), Mon Jun 28 12:09:37 GMT 2004
//
//      COMMENTS:
//           Consistency of the Model.fits file is checked. 
//
//

#include <iostream>
#include <Dal.h>
#include <cassert>
#include <string>
#include <vector>

int main (int argc, char* argv[])
{
  if (argc != 2 )
    {
      std::cerr<<"Usage: "<<argv[0]<<" Model.fits \n";
      return 1;
    }

  std::string name(argv[1]);
  DataSet* set = dataSetServer->open(name, Dal::Read);

  //Name of the tables that have to be checked
  std::vector <std::string>  columns;
  columns.push_back("CHANNEL");
  columns.push_back("RATE");
  columns.push_back("STAT_ERR");
  columns.push_back("QUALITY");
  columns.push_back("AREASCAL");
  columns.push_back("BACKSCAL");

  Table* tab = set->table("SPECTRUM");
  
  for (unsigned int i = 0 ; i < columns.size() ; i++)
    {
      if( tab->column(columns[i]) )
        std::cout << columns[i] << std::endl;
      else
        {
          std::cerr << "columns: columns[i] missing " << std::endl;
          return 1;
        }      
    }

  
  Table* tabRates = set->table("SPECTRUM");
  //assert((tabRates->column("RATE")->rows() == 3400) );

  Table* tabFactors = set->table("FACTORS");

  ColumnData * rateCol = tabFactors->column("Factors")->data();
  real64 *rateDat =  rateCol->real64Data();
  double sumRate = 0;
  for (unsigned i = 0; i <  tabFactors->column("Factors")->rows(); i++)
    sumRate = sumRate+ rateDat[i];
  
  cout << "sum "<< sumRate << endl;

  assert ( (sumRate <= 1.0) && (sumRate > 0.9) );    

  delete rateCol;
  dataSetServer->close(set);
  return 0;
  
}
